#ifndef WIN32
#include <kapp.h>
#include "MainApp.h"
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kaboutdata.h>
#include "config.h"
static const char *description =I18N_NOOP("kmysqladmin");
#else
#include <qapp.h>
#include "MainApp_win32.h"
#endif
#include <stdio.h>
#include <qstring.h>

#include "stringres.h"

int main(int argc, char **argv)
{
#ifndef WIN32
    QString about = GET_TEXT(59);
    about += "\n";
    about += GET_TEXT(60);
    about += "\n2003-02-10";
    KAboutData aboutData("kmysqladmin",I18N_NOOP("kmysqladmin"),
                         VERSION,description,KAboutData::License_GPL,
                         about.latin1(),0,"http://www.alwins-world.de","ral@alwins-world.de");
    aboutData.addAuthor("Rajko Albrecht", "http://www.alwins-world.de","ral@alwins-world.de");
    KCmdLineArgs::init(argc, argv, &aboutData);
    KApplication a(argc, argv);
#else
    QApplication a( argc, argv );
#endif
    CMainApp *dlg = new CMainApp("MainApp",true);
#ifdef WIN32
    a.setMainWidget(dlg);
#endif
    dlg->show();
    
    return a.exec();
}
